# Recorder

This tool can help user record some metrics when you doing machine learning, such as accuracy or auc.

You want to record them as a table and convert them to csv or latex code.

You want to show the recorded table in the progress.

You want to do some easy operation such as mean/max/min in only few code additional.

Then this tool might be your choice!

## Install

> pip install lamda-recorder


